# Welcome to `mosely` 
> A tiny python package for simulating XRF spectra to better understand measurements 


The widespread use of point-and-shoot hand held x-ray fluorescence (XRF) instruments in cultural heritage research, would suggest that it is easy enough for anyone to find out the elemental composition of materials. Alas, due to myriads of emission energies, escape peaks and other nuisances, reliable interpretation of x-ray fluorescence spectra is actually hard. If you are not yet deterred, just read the [Handheld XRF in Cultural Heritage - A practical workbook for conservators](http://www.getty.edu/conservation/publications_resources/pdf_publications/pdf/handheld-xrf-cultural-heritage.pdf) with many, many examples of spectra that was recently made available on-line by the Getty Conservation Institute. 

My take on this as a physicist and a python programmer is that instead of learning from data directly (i.e. staring at measured spectra), a nicer route to insight exists. Due to huge efforts and advances of the open source scientific computing community it is nowadays possible to install readily available python packages and create physics simulations and visualizations with a few lines of computer code. Once you understand why certain patterns of peaks appear, it becomes much more easy to interpret XRF spectra reliably.  

## Installation 

If you would like to adapt this plot to your own needs, for instance to to see what happens if you change beam energy, you can install this package yourself. 

    $ pip install moseley 
    
    

## Usage 

More info follows soon. 
